summaryrefslogtreecommitdiff
path: root/cesar/hle/hle.h
diff options
context:
space:
mode:
authorlaranjeiro2008-04-14 15:44:24 +0000
committerlaranjeiro2008-04-14 15:44:24 +0000
commit046519a971da6005e8fe6c9193a02a2fb308f13f (patch)
treeae44f61774af07f72af82407d2428bd34eae58a4 /cesar/hle/hle.h
parente6edf12d2e6a3bacf2b595ac45c3d2c048383f8a (diff)
Update the HLE to transmit Interface Messages directly to the interface.
git-svn-id: svn+ssh://pessac/svn/cesar/trunk@1824 017c9cb6-072f-447c-8318-d5b54f68fe89
Diffstat (limited to 'cesar/hle/hle.h')
-rw-r--r--cesar/hle/hle.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/cesar/hle/hle.h b/cesar/hle/hle.h
index 1aaeeb39d6..340f715554 100644
--- a/cesar/hle/hle.h
+++ b/cesar/hle/hle.h
@@ -30,6 +30,14 @@
*/
typedef void (*hle_interface_buffer_add_cb_t) (void *user_data, u8 *buffer);
+/**
+ * Provide the MME interfaces to the interface.
+ *
+ * \param user_data the interface user data.
+ * \param buffer the buffer containing the MME.
+ */
+typedef void (*hle_interface_mme_recv_cb_t) (void *user_data, u8 *buffer);
+
/** forward declaration */
typedef struct hle_t hle_t;
@@ -37,12 +45,14 @@ typedef struct hle_t hle_t;
* Initialise the interface to add an Interface buffer.
*
* \param ctx the hle context.
* \param cb the function to call on interface buffer reception.
* \param user_data the user_data to provide on function call.
*/
void
-hle_init_interface_buffer_add_cb (hle_t *ctx, hle_interface_buffer_add_cb_t
- cb, void *user_data);
+hle_init_interface_cb (hle_t *ctx, hle_interface_buffer_add_cb_t buffer_cb,
+ hle_interface_mme_recv_cb_t mme_cb,
+ void *user_data);
/**
* Initialize the HLE.
@@ -37,12 +45,14 @@ typedef struct hle_t hle_t;
*
* \param ctx the hle context.
- * \param cb the function to call on interface buffer reception.
+ * \param buffer_cb the function to call on interface buffer reception.
+ * \param mme_cb the function to call on interface specific MME reception.
* \param user_data the user_data to provide on function call.
*/